How to cite FLiPPR
==================

If you found FLiPPR helpful in your research, please cite us!

| FLiPPR: A Processor for Limited Proteolysis (LiP) Mass Spectrometry Data Sets Built on FragPipe
| Edgar Manriquez-Sandoval, Joy Brewer, Gabriela Lule, Samanta Lopez, and Stephen D. Fried
| Journal of Proteome Research
| doi:10.1021/acs.jproteome.3c00887

`RIS Citation`_

.. _RIS Citation: https://pubs.acs.org/action/downloadCitation?doi=10.1021%2Facs.jproteome.3c00887&include=cit&format=ris&direct=true&downloadFileName=acs.jproteome.3c00887